==> jersey-examples-2.26-b09-all.zip: jersey/examples/sse-twitter-aggregator/src/main/java/org/glassfish/jersey/examples/aggregator/Message.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.examples.aggregator;

import javax.xml.bind.annotation.XmlElement;

import org.eclipse.persistence.oxm.annotations.XmlPath;

/**
 * Message bean.
 *
 * @author Marek Potociar (marek.potociar at oracle.com)
 */
public class Message {

    @XmlElement
    private String text;

    @XmlPath("user/profile_image_url/text()")
    private String profileImg;

    @XmlElement(nillable = true)
    private String rgbColor;

    public Message() {
    }

    public Message(final String text, final String rgbColor, final String profileImg) {
        this.text = text;
        this.rgbColor = rgbColor;
        this.profileImg = profileImg;
    }

    public String getText() {
        return text;
    }

    public String getProfileImg() {
        return profileImg;
    }

    public String getRgbColor() {
        return rgbColor;
    }

    public void setRgbColor(String rgbColor) {
        this.rgbColor = rgbColor;
    }

    @Override
    public String toString() {
        return "Message{"
                + "text='" + text + '\''
                + ", profileImg='" + profileImg + '\''
                + ", rgpColor='" + rgbColor + '\''
                + '}';
    }
}

==> jersey-examples-3.1.6-all.zip: jersey/examples/sse-twitter-aggregator/src/main/java/org/glassfish/jersey/examples/aggregator/Message.java <==
/*
 * Copyright (c) 2012, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package org.glassfish.jersey.examples.aggregator;

import jakarta.xml.bind.annotation.XmlElement;

import org.eclipse.persistence.oxm.annotations.XmlPath;

/**
 * Message bean.
 *
 * @author Marek Potociar
 */
public class Message {

    @XmlElement
    private String text;

    @XmlPath("user/profile_image_url/text()")
    private String profileImg;

    @XmlElement(nillable = true)
    private String rgbColor;

    public Message() {
    }

    public Message(final String text, final String rgbColor, final String profileImg) {
        this.text = text;
        this.rgbColor = rgbColor;
        this.profileImg = profileImg;
    }

    public String getText() {
        return text;
    }

    public String getProfileImg() {
        return profileImg;
    }

    public String getRgbColor() {
        return rgbColor;
    }

    public void setRgbColor(String rgbColor) {
        this.rgbColor = rgbColor;
    }

    @Override
    public String toString() {
        return "Message{"
                + "text='" + text + '\''
                + ", profileImg='" + profileImg + '\''
                + ", rgpColor='" + rgbColor + '\''
                + '}';
    }
}
